@@ -1,5 +1,5 @@
 package Dist::Zilla::Plugin::CopyFilesFromRelease;
-$Dist::Zilla::Plugin::CopyFilesFromRelease::VERSION = '0.003';
+$Dist::Zilla::Plugin::CopyFilesFromRelease::VERSION = '0.004';
 use 5.008;
 use strict;
 use warnings;
@@ -7,10 +7,10 @@ use warnings;
 # ABSTRACT: Copy files from a release (for SCM inclusion, etc.)
 
 use Moose;
-use Moose::Autobox;
 with qw/ Dist::Zilla::Role::AfterRelease /;
 
 use File::Copy ();
+use Path::Tiny;
 
 sub mvp_multivalue_args { qw{ filename match } }
 
@@ -50,19 +50,18 @@ sub after_release {
     $file_match = join '|', '^(?:' . $file_match . ')$', @{ $self->match };
     $file_match = qr/$file_match/;
 
-    $built_in->recurse( callback => sub {
-        my $file = shift;
-        return
-            if $file->is_dir;
+    my $iterator = path($built_in)->iterator({ recurse => 1 });
+    while (my $file = $iterator->()) {
+        next if -d $file;
+
         my $rel_path = $file->relative($built_in);
-        my $unix_style = $rel_path->as_foreign('Unix');
         return
-            unless $unix_style =~ $file_match;
-        my $dest = $root->file($rel_path);
+            unless $rel_path =~ $file_match;
+        my $dest = path($root, $rel_path);
         File::Copy::copy("$file", "$dest")
             or $self->log_fatal("Unable to copy $file to $dest: $!");
         $self->log("Copied $file to $dest");
-    });
+    }
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -81,7 +80,7 @@ Dist::Zilla::Plugin::CopyFilesFromRelease - Copy files from a release (for SCM i
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
